@@ -50,7 +50,7 @@ typedef struct _GnomeRFontClass GnomeRFontClass;
 #include <libgnomeprint/gnome-pgl.h>
 
 GType        gnome_rfont_get_type (void);
-GnomeRFont * gnome_font_get_rfont (GnomeFont *font, const gdouble *transform);
+GnomeRFont * gnome_font_get_rfont (GnomeFont *font, const gdouble *t);
 
 GnomeFont *     gnome_rfont_get_font   (const GnomeRFont *rfont);
 GnomeFontFace * gnome_rfont_get_face   (const GnomeRFont *rfont);
