@@ -33,7 +33,7 @@
  *
  */
 
-/* $Id: ttcr.c,v 1.7 2005/01/04 20:10:46 jody Exp $ */
+/* $Id: ttcr.c 2239 2007-02-28 21:55:18Z tml $ */
 /* @(#)ttcr.c 1.7 03/01/08 SMI */
 
 /*
@@ -51,11 +51,7 @@
 #endif
 #include <fcntl.h>
 #include <stdlib.h>
-#ifdef sun
-#include <strings.h> /* bzero() only in strings.h on Solaris */
-#else
 #include <string.h>
-#endif
 #include <assert.h>
 #include "ttcr.h"
 
@@ -504,7 +500,7 @@ static guint8 *ttmalloc(guint32 nbytes)
     n = (nbytes + 3) & (guint32) ~3;
     res = malloc(n);
     assert(res != 0);
-    bzero(res, n);
+    memset(res, 0, n);
 
     return res;
 }
@@ -1004,7 +1000,7 @@ TrueTypeTable *TrueTypeTableNew_head(guint32 fontRevision,
     PutUInt16(flags, ptr, 16, 1);
     PutUInt16(unitsPerEm, ptr, 18, 1);
     memcpy(ptr+20, created, 8);                   /* Created Long Date */
-    bzero(ptr+28, 8);                             /* Modified Long Date */
+    memset(ptr+28, 0, 8);                         /* Modified Long Date */
     PutUInt16(macStyle, ptr, 44, 1);
     PutUInt16(lowestRecPPEM, ptr, 46, 1);
     PutUInt16(fontDirectionHint, ptr, 48, 1);
